- longlat
a dataframe contains longitude and latitude of point samples.
- trainx
a dataframe or matrix contains columns of predictive variables.
- trainy
a vector of the response variable.
- var.monotone
an optional vector, the same length as the number of
predictors, indicating which variables have a monotone increasing (+1),
decreasing (-1), or arbitrary (0) relationship with the outcome. By default,
a vector of 0 is used.
- family
either a character string specifying the name of the distribution to
use or a list with a component name specifying the distribution and any
additional parameters needed. See gbm for details. By default, "gaussian" is
used.
- n.trees
the total number of trees to fit. This is equivalent to the
number of iterations and the number of basis functions in the additive
expansion. By default, 3000 is used.
- learning.rate
a shrinkage parameter applied to each tree in the
expansion. Also known as step-size reduction.
- interaction.depth
the maximum depth of variable interactions.
1 implies an additive model, 2 implies a model with up to 2-way
interactions, etc. By default, 2 is used.
- bag.fraction
the fraction of the training set observations randomly
selected to propose the next tree in the expansion. By default, 0.5 is used.
- train.fraction
The first train.fraction * nrows(data) observations
are used to fit the gbm and the remainder are used for computing
out-of-sample estimates of the loss function.
- n.minobsinnode
minimum number of observations in the trees terminal
nodes. Note that this is the actual number of observations not the total
weight. By default, 10 is used.
- transformation
transform the residuals of 'gbm' to normalize the data for 'krige';
can be "sqrt" for square root, "arcsine" for arcsine, "log" or "none"
for non transformation. By default, "none" is used.
- weights
an optional vector of weights to be used in the fitting
process. Must be positive but do not need to be normalized.
If keep.data = FALSE in the initial call to gbm then it is the user's
responsibility to resupply the weights to gbm.more. By default, a vector of
1 is used.
- keep.data
a logical variable indicating whether to keep the data and
an index of the data stored with the object. Keeping the data and index
makes subsequent calls to gbm.more faster at the cost of storing an extra
copy of the dataset. By default, 'FALSE' is used.
- verbose
If TRUE, gbm will print out progress and performance
indicators. By default, 'TRUE' is used.
- delta
numeric; to avoid log(0) in the log transformation. The default is 1.
- formula
formula defining the response vector and (possible) regressor.
an object (i.e., 'variogram.formula') for 'variogram' or a formula for
'krige'. see 'variogram' and 'krige' in 'gstat' for details. The default is
'formula = res1 ~ 1'.
- vgm.args
arguments for 'vgm', e.g. variogram model of response
variable and anisotropy parameters. see 'vgm' in 'gstat' for details.
By default, "Sph" is used.
- anis
anisotropy parameters: see notes 'vgm' in 'gstat' for details.
- alpha
direction in plane (x,y). see variogram in 'gstat' for details.
- block
block size. see 'krige' in 'gstat' for details.
- beta
for simple kriging. see 'krige' in 'gstat' for details.
- nmaxkrige
for a local predicting: the number of nearest observations that
should be used for a prediction or simulation, where nearest is defined in
terms of the space of the spatial locations. By default, 12 observations
are used.
- idp
a numeric number specifying the inverse distance weighting power.
- nmaxidw
for a local predicting: the number of nearest observations that
should be used for a prediction or simulation, where nearest is defined in
terms of the space of the spatial locations. By default, 12 observations
are used.
- hybrid.parameter
the default is 2 that is for 'gbmkrigegbmidw';
for 'gbmgbmkrigegbmidw', it needs to be 3.
- lambda,
ranging from 0 to 2; the default is 1 for 'gbmkrigegbmidw'
and 'gbmgbmkrigegbmidw'; and if it is < 1, more weight is placed on 'krige',
otherwise more weight is placed on 'idw'; and if it is 0, 'idw' is not
considered and the resultant methods is 'gbmkrige' when the default
'hybrid.parameter' is used; and if it is 2, then the resultant method is
'gbmidw' when the default 'hybrid.parameter' is used.
- validation
validation methods, include 'LOO': leave-one-out, and 'CV':
cross-validation.
- cv.fold
integer; number of folds in the cross-validation. if > 1,
then apply n-fold cross validation; the default is 10, i.e., 10-fold cross
validation that is recommended.
- predacc
can be either "VEcv" for vecv or "ALL" for all measures
in function pred.acc.
- n.cores
The number of CPU cores to use. See gbm for details. By
default, 6 is used.
- ...
other arguments passed on to 'randomForest', 'krige' and 'gstat'.