- formula.glm
a formula defining the response variable and predictive variables for 'glm'.
- longlat
a dataframe contains longitude and latitude of point samples.
- trainxy
a dataframe contains longitude (long), latitude (lat),
predictive variables and the response variable of point samples.
- predx
a dataframe or matrix contains columns of predictive variables
for the grids to be predicted.
- y
a vector of the response variable in the formula, that is, the left
part of the formula.
- longlatpredx
a dataframe contains longitude and latitude of point locations
(i.e., the centers of grids) to be predicted.
- family
a description of the error distribution and link function to
be used in the model. See '?glm' for details.
- transformation
transform the residuals of 'glm' to normalise the data;
can be "sqrt" for square root, "arcsine" for arcsine, "log" or "none"
for non transformation. By default, "none" is used.
- delta
numeric; to avoid log(0) in the log transformation. The default is 1.
- formula.krige
formula defining the response vector and (possible) regressor.
an object (i.e., 'variogram.formula') for 'variogram' or a formula for
'krige'. see 'variogram' and 'krige' in 'gstat' for details.
- vgm.args
arguments for 'vgm', e.g. variogram model of response
variable and anisotropy parameters. see 'vgm' in 'gstat' for details.
By default, "Sph" is used.
- anis
anisotropy parameters: see notes 'vgm' in 'gstat' for details.
- alpha
direction in plane (x,y). see variogram in 'gstat' for details.
- block
block size. see 'krige' in 'gstat' for details.
- beta
for simple kriging. see 'krige' in 'gstat' for details.
- nmaxkrige
for a local predicting: the number of nearest observations that
should be used for a prediction or simulation, where nearest is defined in
terms of the space of the spatial locations. By default, 12 observations
are used.
- idp
a numeric number specifying the inverse distance weighting power.
- nmaxidw
for a local predicting: the number of nearest observations that
should be used for a prediction or simulation, where nearest is defined in
terms of the space of the spatial locations. By default, 12 observations
are used.
- hybrid.parameter
the default is 2 that is for 'glmkrigeglmidw';
for 'glmglmkrigeglmidw', it needs to be 3.
- lambda,
ranging from 0 to 2; the default is 1 for 'glmkrigeglmidw'
and 'glmglmkrigeglmidw'; and if it is < 1, more weight is placed on 'krige',
otherwise more weight is placed on 'idw'; and if it is 0, 'idw' is not
considered and the resultant methods is 'glmkrige' when the default
'hybrid.parameter' is used; and if it is 2, then the resultant method is
'glmidw' when the default 'hybrid.parameter' is used.
- ...
other arguments passed on to 'glm', 'krige' and 'gstat'.