Learn R Programming

spm2 (version 1.1.3)

spongelonglat: A dataset of sponge species richness in the Timor Sea region, northern Australia marine margin

Description

This dataset contains 77 samples of 7 predictive variables including longitude, latitude, bathy, backscatter and their derived variables. It is the sponge dataset in `spm` package, but with long and lat instead of easting and northing.

Usage

data("spongelonglat")

Arguments

Format

A data frame with 77 observations on the following 8 variables.

sponge

a numeric vector

tpi3

a numeric vector

var7

a numeric vector

entro7

a numeric vector

bs34

a numeric vector

bs11

a numeric vector

long

a numeric vector

lat

a numeric vector

Details

For details, please see sponge dataset in library(spm). Where the long and lat were projected to easting and northing.

References

Li, J., B. Alvarez, J. Siwabessy, M. Tran, Z. Huang, R. Przeslawski, L. Radke, F. Howard, and S. Nichol. 2017. Application of random forest, generalised linear model and their hybrid methods with geostatistical techniques to count data: Predicting sponge species richness. Environmental Modelling & Software, 97: 112-129.

Examples

Run this code
data(spongelonglat)
## maybe str(spongelonglat) ; plot(spongelonglat) ...

Run the code above in your browser using DataLab