- formula
a formula defining the response variable and predictive variables.
- trainxy
a dataframe contains predictive variables and the response
variable of point samples. The location information, longitude (long),
latitude (lat), need to be included in the 'trainx' for spatial predictive
modeling, need to be named as 'long' and 'lat'.
- longlatpredx
a dataframe contains longitude and latitude of point
locations (i.e., the centers of grids) to be predicted, need to be named as
'long' and 'lat'.
- predx
a dataframe or matrix contains columns of predictive variables
for the grids to be predicted.
- scale
A logical vector indicating the variables to be scaled (default: TRUE).
- type
the default setting is 'NULL'. See '?svm' for various options.
- kernel
the default setting is 'radial'. See '?svm' for other options.
- degree
a parameter needed for kernel of type polynomial (default: 3).
- gamma
a parameter needed for all 'kernels' except 'linear'
(default: 1/(data dimension)).
- coef0
a parameter needed for kernels of type 'polynomial' and 'sigmoid'(default: 0).
- cost
cost of constraints violation (default: 1).
- nu
a parameter needed for 'nu-classification', 'nu-regression', and 'one-classification' (default: 0.5).
- tolerance
tolerance of termination criterion (default: 0.001).
- epsilon
'epsilon' in the insensitive-loss function (default: 0.1).
See '?svm' for details.
- ...
other arguments passed on to 'svm'.